__version__ = '1.0.0'

__title__ = "tautulli"
__author__ = 'Nate Harris'
__author_email__ = 'n8gr8gbln@gmail.com'
__github_username__ = "nwithan8"
__copyright__ = "Copyright © 2020 - Nate Harris"
__license__ = 'GNU General Public License v3 (GPLv3)'
__description__ = "A complete Python client for Tautulli's API"
__keywords__ = ["Tautulli", "API", "client", "Plex", "PMS", "Plex Media Server", "media", "server", "JSON"]



from functools import wraps

from tautulli.utils import _success_result, _get_response_data

def set_and_forget(func):
    @wraps(func)
    def wrapper(self, *args, **kwargs) -> bool:
        """
        Return if the ['response']['result'] part of the JSON response == 'success'
        :rtype: bool
        """
        command, params = func(self, *args, **kwargs)
        if not command:
            return False
        json_data = self._get_json(command=command, params=params)
        # print(json_data)
        return _success_result(json_data=json_data)
    return wrapper

def raw_json(func):
    @wraps(func)
    def wrapper(self, *args, **kwargs) -> dict:
        """
        Return the ['response']['data'] part of the JSON response
        :rtype: dict
        """
        command, params = func(self, *args, **kwargs)
        if not command:
            return {}
        json_data = self._get_json(command=command, params=params)
        # print(json_data)
        return _get_response_data(json_data=json_data)
    return wrapper


from typing import Union


class HomeStatsCategory:
    def __init__(self, data: dict):
        self._data = data
        self.name = data.get('stat_id')
        self.type = data.get('stat_type')
        self.rows = data.get('rows')


class HomeStats:
    def __init__(self, data: dict):
        self._data = data
        self.stats = [HomeStatsCategory(data=category) for category in data]

    def get_category(self, category_name: str) -> Union[HomeStatsCategory, None]:
        for category in self.stats:
            if category.name == category_name:
                return category
        return None


class WatchTimeStat:
    def __init__(self, data: dict):
        self._data = data
        self.days = data.get('query_days')
        self.plays = data.get('total_plays')
        self.time = data.get('total_time')


class WatchTimeStats:
    def __init__(self, data: dict):
        self._data = data
        self.stats = [WatchTimeStat(data=stat) for stat in data]

    def get_by_day(self, days: int) -> Union[WatchTimeStat, None]:
        for stat in self.stats:
            if stat.days == days:
                return stat
        return None


class User:
    def __init__(self, data: dict, api):
        self._data = data
        self._api = api
        self.username = data.get('username')
        self.id = data.get('user_id')
        self.shared_libraries = data.get('shared_libraries').split(";")